/******************************************************************************
 * usb_test_main.c: Main program for the USB bases board test for lpc1754 target
 *
 * Copyright (C) 2011, MyVoice
 * All Rights reserved.
 *
 * History
 * 2011.06.29	ver 1.00	Preliminary version, first release
 * 2011.11.21	ver 1.10	Updated to reflect new test set
 *
 * This is the main loop of the lpc1754 target board test program.
 * From this loop all tests are called and user interactions take place.
 *
 * Software License Agreement
 *
 * The software is owned by MyVoice CAD/CAM Services and/or its suppliers, and is
 * protected under applicable copyright laws.  All rights are reserved.  Any
 * use in violation of the foregoing restrictions may subject the user to criminal
 * sanctions under applicable laws, as well as to civil liability for the breach
 * of the terms and conditions of this license.
 *
 * THIS SOFTWARE IS PROVIDED "AS IS".  NO WARRANTIES, WHETHER EXPRESS, IMPLIED
 * OR STATUTORY, INCLUDING, BUT NOT LIMITED TO, IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE APPLY TO THIS SOFTWARE.
 * USE OF THIS SOFTWARE FOR COMMERCIAL DEVELOPMENT AND/OR EDUCATION IS SUBJECT
 * TO A CURRENT END USER LICENSE AGREEMENT (COMMERCIAL OR EDUCATIONAL) WITH
 * MYVOICE CAD/CAM SERVICES.
 *
 */


#include <cr_section_macros.h>
#include <NXP/crp.h>

// Variable to store CRP value in. Will be placed automatically
// by the linker when "Enable Code Read Protect" selected.
// See crp.h header for more information
__CRP const unsigned int CRP_WORD = CRP_NO_CRP ;

#include "small_printf.h"
#include "LPC17xx.h"
#include "usbserial.h"
#include "tests.h"

static uint32_t SysTickDelay = 0;

uint32_t errors = 0;


/*
 * SysTick_Handler - is called after every timeout of the System Tick Timer
 *
 * This instance of SysTick_Handler overwrites the default handler in the
 * startup code and it is called every 1 ms.
 *
 * When a delay is active, SysTickDelay will have a non zero value
 * Decrement this value each tick until it is zero.
 *
 */
void SysTick_Handler(void)
{
	if(SysTickDelay)
		SysTickDelay--;
}

/*
 * delay - delays the given number of system tick timer ticks.
 *
 * This function just initialzes the count-down tick value and waits
 * until the values reaches 0.
 */
void delay (uint32_t delay)
{
	SysTickDelay = delay;

	/*
	 * Wait for the timer to expire.
	 * the __WFI() makes sure that the processor waits for the next
	 * interrupt instead of running around at high speed.
	 */
	while (SysTickDelay) __WFI();
}

/*
 * Main program loop
 */
int main(void)
{
	int c;

	/*
	 * Initialize system functions:
	 * - systick: 1 ms tick
	 * - USBserial
	 * - VCOM: Virtual COM port
	 */
	SysTick_Config(SystemCoreClock / 1000);
	USBserial_init();
	VCOM_init();
	USBserial_connect();

	VCOM_getc();
	while (1) {
		printf("\n\r\n\rlpc1754 target board test (C) MyVoice, 2011\n\n\r");

		printf("\t1 - I2C (EEPROM) test\n\r");
		printf("\t2 - RTC test\n\r");
		printf("\t3 - microSD card test\n\r");
		printf("\t    \n\r");
		printf("\t0 - reset errors\n\r");
		if(errors)
			printf("\n\r*** Errors exist ***\n\r");

		printf(">");

		c = VCOM_getc();
		switch(c)
		{
		case '0':
			errors=0;
			break;
		case '1':
			i2cTest();
			break;
		case '2':
			rtcTest();
			break;
		case '3':
			microSDTest();
			break;
		default:
			break;
		}
	}

	return 0;
}

